@@ -1,4 +1,4 @@
-def openapi(return_class=None, description=None, path_parameters=None, parameters=None, body=None, answer_content=None):
+def openapi(return_class=None, description=None, path_parameters=None, parameters=None):
     def decorate(f):
         def wrapper(*args, **kwargs):
             if len(args) == 1:
@@ -7,9 +7,7 @@ def openapi(return_class=None, description=None, path_parameters=None, parameter
                         'return_class': return_class,
                         'description': description,
                         'path_parameters': path_parameters,
-                        "parameters": parameters,
-                        "body": body,
-                        "answer_content": answer_content
+                        "parameters": parameters
                     }
             return f(*args, **kwargs)
         return wrapper
